@@ -94,7 +94,6 @@ labelptr new_label(objinstptr destinst, stringpart *strptr, int pintype,
    destobject = locdestinst->thisobject;
 
    NEW_LABEL(newlab, destobject);
-   destobject->parts++;
    labeldefaults(*newlab, pintype, x, y);
 
    if (strptr->type == FONT_NAME) {
@@ -148,7 +147,6 @@ labelptr new_temporary_label(objectptr destobject, char *cstr,
    labelptr *newlab;
 
    NEW_LABEL(newlab, destobject);
-   destobject->parts++;
    labeldefaults(*newlab, LOCAL, x, y);
 
    (*newlab)->string->type = TEXT_STRING; /* overwrites FONT record */
@@ -185,7 +183,6 @@ polyptr new_polygon(objinstptr destinst, pointlist *points, int number)
    destobject = locdestinst->thisobject;
 
    NEW_POLY(newpoly, destobject);
-   destobject->parts++;
    polydefaults(*newpoly, 0, 0, 0);
    (*newpoly)->number = number;
    (*newpoly)->points = *points;
@@ -222,7 +219,6 @@ splineptr new_spline(objinstptr destinst, pointlist points)
    destobject = locdestinst->thisobject;
 
    NEW_SPLINE(newspline, destobject);
-   destobject->parts++;
    splinedefaults(*newspline, 0, 0);
 
    for (i = 0; i < 4; i++)
@@ -260,7 +256,6 @@ arcptr new_arc(objinstptr destinst, int radius, int x, int y)
    destobject = locdestinst->thisobject;
 
    NEW_ARC(newarc, destobject);
-   destobject->parts++;
    arcdefaults(*newarc, x, y);
    (*newarc)->radius = (*newarc)->yaxis = radius;
 
@@ -298,7 +293,6 @@ objinstptr new_objinst(objinstptr destinst, objinstptr srcinst, int x, int y)
    destobject = locdestinst->thisobject;
 
    NEW_OBJINST(newobjinst, destobject);
-   destobject->parts++;
    instcopy(*newobjinst, srcinst);
    (*newobjinst)->position.x = x;
    (*newobjinst)->position.y = y;
@@ -381,13 +375,11 @@ void drawdot(int xpos, int ypos)
    
    if ((dotobj = finddot()) != (objectptr)NULL) {
       NEW_OBJINST(newdot, topobject);
-      topobject->parts++;
       instancedefaults(*newdot, dotobj, xpos, ypos);
       register_for_undo(XCF_Dot, UNDO_DONE, areawin->topinstance, *newdot);
    }
    else {
       NEW_ARC(newarc, topobject);
-      topobject->parts++;
       arcdefaults(*newarc, xpos, ypos);
       (*newarc)->radius = 6;
       (*newarc)->yaxis = 6;
@@ -448,7 +440,7 @@ void textbutton(u_char dopin, int x, int y)
    unselect_all();
    NEW_LABEL(newlabel, topobject);
    newselect = allocselect();
-   *newselect = topobject->parts;
+   *newselect = topobject->parts - 1;
    snap(x, y, &userpt);
    labeldefaults(*newlabel, dopin, userpt.x, userpt.y);
 
@@ -799,7 +791,6 @@ Boolean labeltext(int keypressed, char *clientdata)
 	    (*newlabel)->string->nextpart = curpos->nextpart;
 	 }
 	 curpos->nextpart = NULL;
-	 topobject->parts++;
 
 	 /* Adjust position of both labels to retain their original	*/
 	 /* relative positions.						*/
@@ -1058,7 +1049,7 @@ void splinebutton(int x, int y)
    unselect_all();
    NEW_SPLINE(newspline, topobject);
    newselect = allocselect();
-   *newselect = topobject->parts;
+   *newselect = topobject->parts - 1;
 
    snap(x, y, &userpt);
    splinedefaults(*newspline, userpt.x, userpt.y);
@@ -1204,7 +1195,7 @@ void arcbutton(int x, int y)
    unselect_all();
    NEW_ARC(newarc, topobject);
    newselect = allocselect();
-   *newselect = topobject->parts;
+   *newselect = topobject->parts - 1;
    snap(x, y, &userpt);
    saveratio = 1.0;
    arcdefaults(*newarc, userpt.x, userpt.y);
@@ -1213,7 +1204,6 @@ void arcbutton(int x, int y)
    XcSetXORFg(areawin->color, BACKGROUND);
    XcSetFunction(GXxor);
    UDrawArc(*newarc, xobjs.pagelist[areawin->page]->wirewidth);
-   UDrawXLine((*newarc)->position, (*newarc)->position);
 
    xcAddEventHandler(areawin->area, PointerMotionMask, False,
         (xcEventHandler)trackarc, NULL);
@@ -1330,7 +1320,7 @@ void boxbutton(int x, int y)
    unselect_all();
    NEW_POLY(newbox, topobject);
    newselect = allocselect();
-   *newselect = topobject->parts;
+   *newselect = topobject->parts - 1;
    snap(x, y, &userpt);
    polydefaults(*newbox, 4, userpt.x, userpt.y);
 
@@ -1431,7 +1421,7 @@ void startwire(XPoint *userpt)
    unselect_all();
    NEW_POLY(newwire, topobject);
    newselect = allocselect();
-   *newselect = topobject->parts;
+   *newselect = topobject->parts - 1;
 
    /* always start unfilled, unclosed; can fix on next button-push. */
 
@@ -1572,7 +1562,7 @@ void findconstrained(polyptr lastpoly)
 }
 
 /*------------------------------------------------------*/
-/* Track movement of poly, spline, or polygon segments	*/
+/* Track movement of arc, spline, or polygon segments	*/
 /* during edit mode					*/
 /*------------------------------------------------------*/
 
@@ -1813,7 +1803,6 @@ void unjoin()
          cycle = closepoint(oldpoly, &areawin->save);
 	 if (cycle > 0 && cycle < (oldpoly->number - 1)) {
             NEW_POLY(newpoly, topobject);
-	    topobject->parts++;
 	    polycopy(*newpoly, oldpoly);
 	    for (i = cycle; i < oldpoly->number; i++)
 	       (*newpoly)->points[i - cycle] = (*newpoly)->points[i];
@@ -2006,7 +1995,6 @@ void join()
 
    if (allpolys) {
       NEW_POLY(newpoly, topobject);
-      topobject->parts++;
 
       (*newpoly)->number = numpoints;
       (*newpoly)->points = (pointlist) malloc(numpoints * sizeof(XPoint));
@@ -2061,7 +2049,6 @@ void join()
       (*newpath)->parts = 0;
       (*newpath)->plist = (genericptr *) malloc(sizeof(genericptr));
       (*newpath)->passed = NULL;
-      topobject->parts++;
 
       /* copy the elements from the top level into the path structure */
 
@@ -2089,8 +2076,6 @@ void join()
 	       splinecopy(*newspline, copyspline);
 	    } break;
 	 }
-
-	 (*newpath)->parts++;
 	 newelem = (*newpath)->plist + (*newpath)->parts - 1;
 
 	 /* reverse point order if necessary */
@@ -2199,6 +2184,7 @@ void wire_op(int op, int x, int y)
       free(newwire);
       newwire = NULL;
       eventmode = NORMAL_MODE;
+      topobject->parts--;
    }
 
    /* back up one point; prevent length zero wires */
@@ -2209,6 +2195,7 @@ void wire_op(int op, int x, int y)
 	 free(newwire);
 	 newwire = NULL;
          eventmode = NORMAL_MODE;
+         topobject->parts--;
       }
       else {
          if (--newwire->number == 2) newwire->style = UNCLOSED |
@@ -2245,7 +2232,6 @@ void wire_op(int op, int x, int y)
 
          XcSetFunction(GXcopy);
          XcTopSetForeground(newwire->color);
-	 topobject->parts++;
 	 incr_changes(topobject);
 	 if (!nonnetwork(newwire)) invalidate_netlist(topobject);
 	 register_for_undo(XCF_Wire, UNDO_MORE, areawin->topinstance, newwire);
