@@ -117,9 +117,9 @@ Boolean transform_graphic(graphicptr gp)
     int screen = DefaultScreen(dpy);
     static GC cmgc = (GC)NULL;
 
-    tscale = UTopTransScale(1.0);
+    tscale = UTopScale();
     scale = gp->scale * tscale;
-    rotation = gp->rotation + UTopRotate();
+    rotation = gp->rotation + UTopRotation();
 
     if (rotation >= 360) rotation -= 360;
     else if (rotation < 0) rotation += 360;
@@ -393,7 +393,6 @@ graphicptr new_graphic(objinstptr destinst, char *filename, int px, int py)
 
     iptr->refcount++;
     NEW_GRAPHIC(gp, destobject);
-    destobject->parts++;
 
     (*gp)->scale = 1.0;
     (*gp)->position.x = px;
