@@ -619,6 +619,7 @@ void composepagelib(short mode)
       (*drawbox)->number = 4;
       (*drawbox)->points = (pointlist) malloc(4 * sizeof(XPoint));
       (*drawbox)->passed = NULL;
+      (*drawbox)->cycle = NULL;
       pointptr = (*drawbox)->points;
       pointptr->x = (i % gxsize) * xdel + margin;
       pointptr->y = -(i / gxsize) * ydel - margin;
@@ -631,7 +632,6 @@ void composepagelib(short mode)
       pointptr = (*drawbox)->points + 3;
       pointptr->x = (i % gxsize) * xdel + margin;
       pointptr->y = -((i / gxsize) + 1) * ydel + margin;
-      directory->parts++;
 
       /* each page gets its name printed at the bottom */
 
@@ -648,7 +648,6 @@ void composepagelib(short mode)
 	 strptr->data.string = (char *) malloc(1 + strlen(libobj->name));
 	 strcpy(strptr->data.string, libobj->name);
 	 (*pagelabel)->justify = TOP | NOTBOTTOM | NOTLEFT;
-	 directory->parts++;
       }
    }
 
@@ -892,7 +891,6 @@ void composelib(short mode)
 	 /* char *locobjname; (jdk) */
 
 	 NEW_LABEL(drawname, libpage);
-         libpage->parts++;
 	 labeldefaults(*drawname, False, 0, 0);
 	 (*drawname)->color = (spec->virtual) ?
 			OFFBUTTONCOLOR : DEFAULTCOLOR;
@@ -1495,7 +1493,6 @@ void copycat()
 	       instcopy(*ninst, cinst);
                } break;
          }
-	 (*newobj)->parts++;
       }
    }
 
@@ -1603,7 +1600,6 @@ void catalog_op(int op, int x, int y)
 	          for (newselect = areawin->selectlist; newselect <
 		     areawin->selectlist + areawin->selects; newselect++) {
 		     NEW_OBJINST(newobject, topobject);
-		     topobject->parts++;
 		     instcopy(*newobject, TOOBJINST(libpage->plist + *newselect));
 		     /* color should be recast as current color */
 		     (*newobject)->color = areawin->color;
@@ -1621,7 +1617,6 @@ void catalog_op(int op, int x, int y)
 
 	          if (!flag) {
 		     NEW_OBJINST(newobject, topobject);
-                     topobject->parts++;
 		     instcopy(*newobject, *libobj);
 		     (*newobject)->color = areawin->color;
                      (*newobject)->position.x = areawin->save.x;
