@@ -617,8 +617,7 @@ int findsubschems(int toppage, objectptr cschem, int level, short *pagelist,
 	          if ((ops != NULL) && (ops->type == XC_STRING)) {
 	             char *filename = textprint(ops->parameter.string, cinst);
 		     if (!strcmp(filename, "%n") || !strcmp(filename, "%N") ||
-			  ((xobjs.pagelist[pageno]->filename != NULL)  &&
-			  (!strcmp(filename, xobjs.pagelist[pageno]->filename)))) {
+			  !strcmp(filename, xobjs.pagelist[pageno]->filename)) {
 		        free(filename);
 		        continue;
 		     }
@@ -955,7 +954,6 @@ void swapschem(int allow_create, int libnum, char *fullname)
 	       (*pinlab)->passed = NULL;
 	       u2u_snap(&((*pinlab)->position));
 	       (*pinlab)->string = stringcopy(lpin->string);
-	       topobject->parts++;
 	       incr_changes(topobject);
 	    }
          }
