@@ -193,6 +193,8 @@ void gendrawselected(short *newselect, objectptr curobj, objinstptr curinst)
    /* Don't draw selection color when selecting for edit */
    if (eventmode == PENDING_MODE) return;
 
+   if (*newselect >= curobj->parts) return;	// Safety check
+
    XcSetFunction(GXcopy);
    XcSetForeground(BACKGROUND);
    geneasydraw(*newselect, DOFORALL, curobj, curinst);
@@ -848,7 +850,7 @@ Boolean areaelement(genericptr *curgen, XPoint *boxpts, Boolean is_path, short l
 	   /* check center of arcs */
 
 	   selected = test_insideness(TOARC(curgen)->position.x,
-		TOARC(curgen)->position.x, boxpts);
+		TOARC(curgen)->position.y, boxpts);
 	   break;
 
       case(POLYGON):
@@ -1099,7 +1101,13 @@ void draw_normal_selected(objectptr thisobj, objinstptr thisinst)
    for (i = 0; i < areawin->selects; i++) {
       lastselect = areawin->selectlist + i;
       XTopSetForeground(SELTOCOLOR(lastselect)); 
-      geneasydraw(*lastselect, SELTOCOLOR(lastselect), thisobj, thisinst);
+
+      // Check is necessary due to failure to remove newly-created items
+      // from selection list when they are canceled.
+
+      if (*lastselect < thisobj->parts) {
+         geneasydraw(*lastselect, SELTOCOLOR(lastselect), thisobj, thisinst);
+      }
    }
 }
 
