@@ -146,7 +146,7 @@ ERROR: Cannot compile without knowing the size of a pointer.  See xcircuit.h.
 	(a)->plist = (genericptr *) realloc ((a)->plist, \
 	((a)->parts + 1) * sizeof(genericptr))
 
-#define ENDPART		topobject->plist + topobject->parts
+#define ENDPART		topobject->plist + topobject->parts - 1
 #define EDITPART	topobject->plist + *areawin->selectlist
 
 /* Type checks (argument "a" is type genericptr) */
@@ -199,36 +199,43 @@ ERROR: Cannot compile without knowing the size of a pointer.  See xcircuit.h.
 	PLIST_INCR(b); \
 	a = (polyptr *)b->plist + b->parts; \
 	*a = (polyptr) malloc(sizeof(polygon)); \
+	b->parts++; \
 	(*a)->type = POLYGON
 #define NEW_LABEL(a,b) \
 	PLIST_INCR(b); \
 	a = (labelptr *)b->plist + b->parts; \
 	*a = (labelptr) malloc(sizeof(label)); \
+	b->parts++; \
 	(*a)->type = LABEL
 #define NEW_OBJINST(a,b) \
 	PLIST_INCR(b); \
 	a = (objinstptr *)b->plist + b->parts; \
 	*a = (objinstptr) malloc(sizeof(objinst)); \
+	b->parts++; \
 	(*a)->type = OBJINST
 #define NEW_ARC(a,b) \
 	PLIST_INCR(b); \
 	a = (arcptr *)b->plist + b->parts; \
 	*a = (arcptr) malloc(sizeof(arc)); \
+	b->parts++; \
 	(*a)->type = ARC
 #define NEW_SPLINE(a,b) \
 	PLIST_INCR(b); \
 	a = (splineptr *)b->plist + b->parts; \
 	*a = (splineptr) malloc(sizeof(spline)); \
+	b->parts++; \
 	(*a)->type = SPLINE
 #define NEW_PATH(a,b) \
 	PLIST_INCR(b); \
 	a = (pathptr *)b->plist + b->parts; \
 	*a = (pathptr) malloc(sizeof(path)); \
+	b->parts++; \
 	(*a)->type = PATH
 #define NEW_GRAPHIC(a,b) \
 	PLIST_INCR(b); \
 	a = (graphicptr *)b->plist + b->parts; \
 	*a = (graphicptr) malloc(sizeof(graphic)); \
+	b->parts++; \
 	(*a)->type = GRAPHIC
 
 /*----------------------------------------------------------------------*/
